@@ -7,13 +7,37 @@ from helix_catalog_sdk.enums import HelixEnvironment
 
 
 class ResourceItem:
-    JSON_KEYS = ("name", "path", "path_slug")
+    JSON_KEYS = (
+        "name",
+        "path",
+        "path_slug",
+        "last_processed",
+        "date_segment",
+        "date_format",
+    )
 
-    def __init__(self, content: SimpleNamespace, base_connection_formatted: str):
+    def __init__(
+        self,
+        content: SimpleNamespace,
+        base_connection_formatted: str,
+        environment: HelixEnvironment,
+    ):
         self.name = content.name
         self.path = content.path
         self.path_slug = getattr(content, "path_slug", None)
         self.base_connection_formatted = base_connection_formatted
+        self.date_segment = None
+        if hasattr(content, "date_segment") and content.date_segment is not None:
+            self.date_segment = content.date_segment
+        self.date_format = None
+        if hasattr(content, "date_format") and content.date_format is not None:
+            self.date_format = content.date_format
+        self.last_processed = None
+        if hasattr(content, "last_processed") and content.last_processed is not None:
+            self.last_processed = LastProcessed(content.last_processed, environment)
+        self.path_extension = None
+        if hasattr(content, "path_extension") and content.path_extension is not None:
+            self.path_extension = content.path_extension
 
     @property
     def full_path_slug(self) -> str:
@@ -27,7 +51,10 @@ class ResourceItem:
 
     def matches_path(self, path: str) -> bool:
         if self.full_path_slug and self.full_path_slug in path:
-            return True
+            if self.path_extension:
+                return path.endswith(self.path_extension)
+            else:
+                return True
         return False
 
     @property
@@ -60,7 +87,7 @@ class DataSource:
         self.resources: List[ResourceItem] = []
         for resource_item in content.resources:
             self.resources.append(
-                ResourceItem(resource_item, self.base_connection_formatted)
+                ResourceItem(resource_item, self.base_connection_formatted, environment)
             )
         self.pipeline_subscriptions: List[PipelineSubscription] = []
         for pipeline_subscription in content.pipeline_subscriptions:
@@ -139,3 +166,30 @@ class PipelineSubscription:
     @property
     def json_dict(self) -> Dict[str, Any]:
         return self.__dict__
+
+
+class LastProcessed:
+    def __init__(self, content: SimpleNamespace, environment: HelixEnvironment):
+        self.dev = content.dev
+        self.production = content.production
+        self.staging = content.staging
+        self.qa = content.qa
+
+    @property
+    def json_dict(self) -> Dict[str, Any]:
+        return self.__dict__
+
+    def set_last_processed(
+        self, last_processed_value: str, environment: HelixEnvironment
+    ) -> None:
+        self.json_dict[environment.name.lower()] = last_processed_value
+
+    def get_last_processed(self, environment: HelixEnvironment) -> str:
+        last_processed_item: str = self.dev
+        if environment == HelixEnvironment.PRODUCTION:
+            last_processed_item = self.production
+        elif environment == HelixEnvironment.STAGING:
+            last_processed_item = self.staging
+        elif environment == HelixEnvironment.QA:
+            last_processed_item = self.qa
+        return last_processed_item
